# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/object.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/object.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n!machinetalk/protobuf/object.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/types.proto\",\n\x08Instance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x0f:\x06\x92?\x03H\xbc\x05\"\xb7\x01\n\x13ServiceAnnouncement\x12\'\n\x05stype\x18\x01 \x02(\x0e\x32\x18.machinetalk.ServiceType\x12\x12\n\x07version\x18\x02 \x02(\x07:\x01\x30\x12\x13\n\x08instance\x18\x03 \x02(\x07:\x01\x30\x12$\n\x03\x61pi\x18\x08 \x02(\x0e\x32\x17.machinetalk.ServiceAPI\x12\x0b\n\x03uri\x18\x06 \x02(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t:\x06\x92?\x03H\xbd\x05\"\xab\x01\n\nOriginator\x12\'\n\x06origin\x18\x01 \x01(\x0e\x32\x17.machinetalk.OriginType\x12)\n\x06\x64\x65tail\x18\x02 \x01(\x0e\x32\x19.machinetalk.OriginDetail\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\x0f\x12\'\n\x08instance\x18\x05 \x01(\x0b\x32\x15.machinetalk.Instance:\x06\x92?\x03H\xbe\x05\"\x8b\x01\n\x07\x41nError\x12\x12\n\nerror_code\x18\x01 \x02(\x0f\x12\'\n\x08severity\x18\x02 \x01(\x0e\x32\x15.machinetalk.Severity\x12\x12\n\nerror_text\x18\x03 \x01(\t\x12\'\n\x06origin\x18\x04 \x01(\x0b\x32\x17.machinetalk.Originator:\x06\x92?\x03H\xbf\x05\"\x8e\x02\n\x03Pin\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.machinetalk.ValueType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\x07\x12)\n\x03\x64ir\x18\x04 \x01(\x0e\x32\x1c.machinetalk.HalPinDirection\x12\x0e\n\x06halbit\x18\x05 \x01(\x08\x12\x10\n\x08halfloat\x18\x06 \x01(\x01\x12\x0e\n\x06hals32\x18\x07 \x01(\x0f\x12\x0e\n\x06halu32\x18\x08 \x01(\x07\x12\r\n\x05owner\x18\t \x01(\x0f\x12\x0e\n\x06linked\x18\n \x01(\x08\x12\x0f\n\x07oldname\x18\x0b \x01(\t\x12\x0f\n\x07\x65psilon\x18\x0c \x01(\x01\x12\r\n\x05\x66lags\x18\r \x01(\x07:\x06\x92?\x03H\xc0\x05\"\xe6\x01\n\x06Signal\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.machinetalk.ValueType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\x07\x12\x0e\n\x06halbit\x18\x05 \x01(\x08\x12\x10\n\x08halfloat\x18\x06 \x01(\x01\x12\x0e\n\x06hals32\x18\x07 \x01(\x0f\x12\x0e\n\x06halu32\x18\x08 \x01(\x07\x12\x0e\n\x06strval\x18\t \x01(\t\x12\x0c\n\x04\x62lob\x18\n \x01(\x0c\x12\x0f\n\x07readers\x18\x0b \x01(\x07\x12\x0f\n\x07writers\x18\x0c \x01(\x07\x12\x0e\n\x06\x62idirs\x18\r \x01(\x07:\x06\x92?\x03H\xc1\x05\"\xa2\x02\n\x05Param\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.machinetalk.ValueType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06handle\x18\x03 \x01(\x07\x12\x0e\n\x06halbit\x18\x05 \x01(\x08\x12\x10\n\x08halfloat\x18\x06 \x01(\x01\x12\x0e\n\x06hals32\x18\x07 \x01(\x0f\x12\x0e\n\x06halu32\x18\x08 \x01(\x07\x12\x0e\n\x06strval\x18\t \x01(\t\x12\x0c\n\x04\x62lob\x18\n \x01(\x0c\x12+\n\x03\x64ir\x18\x0b \x01(\x0e\x32\x1e.machinetalk.HalParamDirection\x12\x0f\n\x07oldname\x18\x0c \x01(\t\x12\r\n\x05owner\x18\r \x01(\x0f\x12\x0f\n\x07runtime\x18\x0e \x01(\x0f\x12\x0f\n\x07maytime\x18\x0f \x01(\x0f:\x06\x92?\x03H\xc2\x05\"\xca\x01\n\x08\x46unction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x10\n\x08owner_id\x18\x03 \x01(\x07\x12\r\n\x05users\x18\x04 \x01(\x07\x12\x0f\n\x07runtime\x18\x05 \x01(\x07\x12\x0f\n\x07maxtime\x18\x06 \x01(\x07\x12\x11\n\treentrant\x18\x07 \x01(\x08\x12\'\n\x04type\x18\x08 \x01(\x0e\x32\x19.machinetalk.HalFunctType\x12\x19\n\x11maxtime_increased\x18\t \x01(\x08:\x06\x92?\x03H\xc3\x05\"\x94\x01\n\x06Thread\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x0f\n\x07uses_fp\x18\x03 \x01(\x08\x12\x0e\n\x06period\x18\x04 \x01(\x07\x12\x10\n\x08priority\x18\x05 \x01(\x0f\x12\x0f\n\x07task_id\x18\x06 \x01(\x07\x12\x0e\n\x06\x63pu_id\x18\x07 \x01(\x07\x12\x10\n\x08\x66unction\x18\x08 \x03(\t:\x06\x92?\x03H\xc4\x05\"\xe6\x02\n\tComponent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05ninst\x18\x02 \x01(\x07\x12\x0f\n\x07\x63omp_id\x18\x04 \x01(\x0f\x12\x0c\n\x04type\x18\x05 \x01(\x07\x12\r\n\x05state\x18\x06 \x01(\x07\x12\x13\n\x0blast_update\x18\x07 \x01(\x07\x12\x12\n\nlast_bound\x18\x08 \x01(\x07\x12\x14\n\x0clast_unbound\x18\t \x01(\x07\x12\x0b\n\x03pid\x18\n \x01(\x07\x12\x0c\n\x04\x61rgs\x18\x0b \x01(\t\x12\r\n\x05timer\x18\x0c \x01(\x0f\x12\x10\n\x08userarg1\x18\x0e \x01(\x0f\x12\x10\n\x08userarg2\x18\x0f \x01(\x0f\x12\x1d\n\x03pin\x18\x10 \x03(\x0b\x32\x10.machinetalk.Pin\x12!\n\x05param\x18\x11 \x03(\x0b\x32\x12.machinetalk.Param\x12$\n\x05\x66unct\x18\x13 \x03(\x0b\x32\x15.machinetalk.Function\x12\x11\n\tno_create\x18\x12 \x01(\x08:\x06\x92?\x03H\xc5\x05\"\xee\x01\n\x04Ring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\r\n\x05owner\x18\x03 \x01(\x0f\x12\x0e\n\x06stream\x18\x04 \x01(\x08\x12\x0e\n\x06wmutex\x18\x05 \x01(\x08\x12\x0e\n\x06rmutex\x18\x06 \x01(\x08\x12\x11\n\trtapi_shm\x18\x07 \x01(\x08\x12\x0e\n\x06reader\x18\x08 \x01(\x0f\x12\x0e\n\x06writer\x18\t \x01(\x0f\x12\x12\n\ntotal_size\x18\n \x01(\x0f\x12\x12\n\nscratchpad\x18\x0b \x01(\x0f\x12\x13\n\x0bring_shmkey\x18\x0c \x01(\x0f\x12\x11\n\tencodings\x18\r \x01(\x07:\x06\x92?\x03H\xc6\x05\"\xe5\x01\n\x06Member\x12&\n\x05mtype\x18\x01 \x01(\x0e\x32\x17.machinetalk.ObjectType\x12\x10\n\x08userarg1\x18\x02 \x01(\x0f\x12\x0f\n\x07\x65psilon\x18\x03 \x01(\x01\x12#\n\x06signal\x18\x04 \x01(\x0b\x32\x13.machinetalk.Signal\x12\x11\n\tgroupname\x18\x05 \x01(\t\x12\x0e\n\x06handle\x18\x06 \x01(\x07\x12\x1d\n\x03pin\x18\x07 \x01(\x0b\x32\x10.machinetalk.Pin\x12!\n\x05param\x18\x08 \x01(\x0b\x32\x12.machinetalk.Param:\x06\x92?\x03H\xc7\x05\"\x88\x01\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x10\n\x08userarg1\x18\x04 \x01(\x0f\x12\x10\n\x08userarg2\x18\x05 \x01(\x0f\x12\x10\n\x08refcount\x18\x06 \x01(\x0f\x12#\n\x06member\x18\x07 \x03(\x0b\x32\x13.machinetalk.Member:\x06\x92?\x03H\xc8\x05\"_\n\x12ProtocolParameters\x12\x17\n\x0fkeepalive_timer\x18\x01 \x01(\x0f\x12\x13\n\x0bgroup_timer\x18\x02 \x01(\x0f\x12\x13\n\x0brcomp_timer\x18\x03 \x01(\x0f:\x06\x92?\x03H\xc9\x05\"\x84\x01\n\x06Vtable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06handle\x18\x02 \x01(\x07\x12\x10\n\x08owner_id\x18\x03 \x01(\x0f\x12\x0f\n\x07\x63ontext\x18\x05 \x01(\x07\x12\x10\n\x08refcount\x18\x06 \x01(\x0f\x12\x0f\n\x07version\x18\x07 \x01(\x0f\x12\x0e\n\x06vtable\x18\x08 \x01(\x06:\x06\x92?\x03H\xca\x05\"\xc9\x01\n\x04Inst\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63omp_id\x18\x02 \x01(\x0f\x12\x0f\n\x07inst_id\x18\x03 \x01(\x07\x12\x11\n\tinst_size\x18\x04 \x01(\x07\x12\x0e\n\x06vtable\x18\x05 \x01(\x06\x12\x1d\n\x03pin\x18\x10 \x03(\x0b\x32\x10.machinetalk.Pin\x12!\n\x05param\x18\x11 \x03(\x0b\x32\x12.machinetalk.Param\x12$\n\x05\x66unct\x18\x13 \x03(\x0b\x32\x15.machinetalk.Function:\x06\x92?\x03H\xcb\x05')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_INSTANCE = _descriptor.Descriptor(
  name='Instance',
  full_name='machinetalk.Instance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Instance.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Instance.id', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\274\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=163,
)


_SERVICEANNOUNCEMENT = _descriptor.Descriptor(
  name='ServiceAnnouncement',
  full_name='machinetalk.ServiceAnnouncement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='machinetalk.ServiceAnnouncement.stype', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='machinetalk.ServiceAnnouncement.version', index=1,
      number=2, type=7, cpp_type=3, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance', full_name='machinetalk.ServiceAnnouncement.instance', index=2,
      number=3, type=7, cpp_type=3, label=2,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='api', full_name='machinetalk.ServiceAnnouncement.api', index=3,
      number=8, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uri', full_name='machinetalk.ServiceAnnouncement.uri', index=4,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='machinetalk.ServiceAnnouncement.description', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\275\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=349,
)


_ORIGINATOR = _descriptor.Descriptor(
  name='Originator',
  full_name='machinetalk.Originator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.Originator.origin', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='detail', full_name='machinetalk.Originator.detail', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=10,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Originator.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Originator.id', index=3,
      number=4, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance', full_name='machinetalk.Originator.instance', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\276\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=523,
)


_ANERROR = _descriptor.Descriptor(
  name='AnError',
  full_name='machinetalk.AnError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='machinetalk.AnError.error_code', index=0,
      number=1, type=15, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='severity', full_name='machinetalk.AnError.severity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_text', full_name='machinetalk.AnError.error_text', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.AnError.origin', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\277\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=665,
)


_PIN = _descriptor.Descriptor(
  name='Pin',
  full_name='machinetalk.Pin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Pin.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Pin.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Pin.handle', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dir', full_name='machinetalk.Pin.dir', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=16,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Pin.halbit', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Pin.halfloat', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Pin.hals32', index=6,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Pin.halu32', index=7,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='machinetalk.Pin.owner', index=8,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linked', full_name='machinetalk.Pin.linked', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='oldname', full_name='machinetalk.Pin.oldname', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='machinetalk.Pin.epsilon', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='flags', full_name='machinetalk.Pin.flags', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\300\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=938,
)


_SIGNAL = _descriptor.Descriptor(
  name='Signal',
  full_name='machinetalk.Signal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Signal.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Signal.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Signal.handle', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Signal.halbit', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Signal.halfloat', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Signal.hals32', index=5,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Signal.halu32', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strval', full_name='machinetalk.Signal.strval', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blob', full_name='machinetalk.Signal.blob', index=8,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='readers', full_name='machinetalk.Signal.readers', index=9,
      number=11, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='writers', full_name='machinetalk.Signal.writers', index=10,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bidirs', full_name='machinetalk.Signal.bidirs', index=11,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\301\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=1171,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='machinetalk.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Param.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Param.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Param.handle', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halbit', full_name='machinetalk.Param.halbit', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halfloat', full_name='machinetalk.Param.halfloat', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hals32', full_name='machinetalk.Param.hals32', index=5,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='halu32', full_name='machinetalk.Param.halu32', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strval', full_name='machinetalk.Param.strval', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blob', full_name='machinetalk.Param.blob', index=8,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dir', full_name='machinetalk.Param.dir', index=9,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=64,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='oldname', full_name='machinetalk.Param.oldname', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='machinetalk.Param.owner', index=11,
      number=13, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='machinetalk.Param.runtime', index=12,
      number=14, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maytime', full_name='machinetalk.Param.maytime', index=13,
      number=15, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\302\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1464,
)


_FUNCTION = _descriptor.Descriptor(
  name='Function',
  full_name='machinetalk.Function',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Function.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Function.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='machinetalk.Function.owner_id', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='users', full_name='machinetalk.Function.users', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='machinetalk.Function.runtime', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxtime', full_name='machinetalk.Function.maxtime', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reentrant', full_name='machinetalk.Function.reentrant', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Function.type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='maxtime_increased', full_name='machinetalk.Function.maxtime_increased', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\303\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1669,
)


_THREAD = _descriptor.Descriptor(
  name='Thread',
  full_name='machinetalk.Thread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Thread.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Thread.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uses_fp', full_name='machinetalk.Thread.uses_fp', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='period', full_name='machinetalk.Thread.period', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='priority', full_name='machinetalk.Thread.priority', index=4,
      number=5, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='machinetalk.Thread.task_id', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cpu_id', full_name='machinetalk.Thread.cpu_id', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='function', full_name='machinetalk.Thread.function', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\304\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1672,
  serialized_end=1820,
)


_COMPONENT = _descriptor.Descriptor(
  name='Component',
  full_name='machinetalk.Component',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Component.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ninst', full_name='machinetalk.Component.ninst', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comp_id', full_name='machinetalk.Component.comp_id', index=2,
      number=4, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Component.type', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.Component.state', index=4,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_update', full_name='machinetalk.Component.last_update', index=5,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_bound', full_name='machinetalk.Component.last_bound', index=6,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_unbound', full_name='machinetalk.Component.last_unbound', index=7,
      number=9, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='machinetalk.Component.pid', index=8,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='machinetalk.Component.args', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timer', full_name='machinetalk.Component.timer', index=10,
      number=12, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg1', full_name='machinetalk.Component.userarg1', index=11,
      number=14, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg2', full_name='machinetalk.Component.userarg2', index=12,
      number=15, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Component.pin', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Component.param', index=14,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='funct', full_name='machinetalk.Component.funct', index=15,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='no_create', full_name='machinetalk.Component.no_create', index=16,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\305\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1823,
  serialized_end=2181,
)


_RING = _descriptor.Descriptor(
  name='Ring',
  full_name='machinetalk.Ring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Ring.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Ring.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='machinetalk.Ring.owner', index=2,
      number=3, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stream', full_name='machinetalk.Ring.stream', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wmutex', full_name='machinetalk.Ring.wmutex', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rmutex', full_name='machinetalk.Ring.rmutex', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rtapi_shm', full_name='machinetalk.Ring.rtapi_shm', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reader', full_name='machinetalk.Ring.reader', index=7,
      number=8, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='writer', full_name='machinetalk.Ring.writer', index=8,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='machinetalk.Ring.total_size', index=9,
      number=10, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='scratchpad', full_name='machinetalk.Ring.scratchpad', index=10,
      number=11, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ring_shmkey', full_name='machinetalk.Ring.ring_shmkey', index=11,
      number=12, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encodings', full_name='machinetalk.Ring.encodings', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\306\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2184,
  serialized_end=2422,
)


_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='machinetalk.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mtype', full_name='machinetalk.Member.mtype', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg1', full_name='machinetalk.Member.userarg1', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='machinetalk.Member.epsilon', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='signal', full_name='machinetalk.Member.signal', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='groupname', full_name='machinetalk.Member.groupname', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Member.handle', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Member.pin', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Member.param', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\307\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2425,
  serialized_end=2654,
)


_GROUP = _descriptor.Descriptor(
  name='Group',
  full_name='machinetalk.Group',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Group.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Group.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg1', full_name='machinetalk.Group.userarg1', index=2,
      number=4, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='userarg2', full_name='machinetalk.Group.userarg2', index=3,
      number=5, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refcount', full_name='machinetalk.Group.refcount', index=4,
      number=6, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member', full_name='machinetalk.Group.member', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\310\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2657,
  serialized_end=2793,
)


_PROTOCOLPARAMETERS = _descriptor.Descriptor(
  name='ProtocolParameters',
  full_name='machinetalk.ProtocolParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keepalive_timer', full_name='machinetalk.ProtocolParameters.keepalive_timer', index=0,
      number=1, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_timer', full_name='machinetalk.ProtocolParameters.group_timer', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rcomp_timer', full_name='machinetalk.ProtocolParameters.rcomp_timer', index=2,
      number=3, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\311\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2795,
  serialized_end=2890,
)


_VTABLE = _descriptor.Descriptor(
  name='Vtable',
  full_name='machinetalk.Vtable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Vtable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='handle', full_name='machinetalk.Vtable.handle', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner_id', full_name='machinetalk.Vtable.owner_id', index=2,
      number=3, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='machinetalk.Vtable.context', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='refcount', full_name='machinetalk.Vtable.refcount', index=4,
      number=6, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='machinetalk.Vtable.version', index=5,
      number=7, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vtable', full_name='machinetalk.Vtable.vtable', index=6,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\312\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2893,
  serialized_end=3025,
)


_INST = _descriptor.Descriptor(
  name='Inst',
  full_name='machinetalk.Inst',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='machinetalk.Inst.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='comp_id', full_name='machinetalk.Inst.comp_id', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inst_id', full_name='machinetalk.Inst.inst_id', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inst_size', full_name='machinetalk.Inst.inst_size', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vtable', full_name='machinetalk.Inst.vtable', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pin', full_name='machinetalk.Inst.pin', index=5,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='param', full_name='machinetalk.Inst.param', index=6,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='funct', full_name='machinetalk.Inst.funct', index=7,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\313\005')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3028,
  serialized_end=3229,
)

_SERVICEANNOUNCEMENT.fields_by_name['stype'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._SERVICETYPE
_SERVICEANNOUNCEMENT.fields_by_name['api'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._SERVICEAPI
_ORIGINATOR.fields_by_name['origin'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._ORIGINTYPE
_ORIGINATOR.fields_by_name['detail'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._ORIGINDETAIL
_ORIGINATOR.fields_by_name['instance'].message_type = _INSTANCE
_ANERROR.fields_by_name['severity'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._SEVERITY
_ANERROR.fields_by_name['origin'].message_type = _ORIGINATOR
_PIN.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_PIN.fields_by_name['dir'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._HALPINDIRECTION
_SIGNAL.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_PARAM.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._VALUETYPE
_PARAM.fields_by_name['dir'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._HALPARAMDIRECTION
_FUNCTION.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._HALFUNCTTYPE
_COMPONENT.fields_by_name['pin'].message_type = _PIN
_COMPONENT.fields_by_name['param'].message_type = _PARAM
_COMPONENT.fields_by_name['funct'].message_type = _FUNCTION
_MEMBER.fields_by_name['mtype'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._OBJECTTYPE
_MEMBER.fields_by_name['signal'].message_type = _SIGNAL
_MEMBER.fields_by_name['pin'].message_type = _PIN
_MEMBER.fields_by_name['param'].message_type = _PARAM
_GROUP.fields_by_name['member'].message_type = _MEMBER
_INST.fields_by_name['pin'].message_type = _PIN
_INST.fields_by_name['param'].message_type = _PARAM
_INST.fields_by_name['funct'].message_type = _FUNCTION
DESCRIPTOR.message_types_by_name['Instance'] = _INSTANCE
DESCRIPTOR.message_types_by_name['ServiceAnnouncement'] = _SERVICEANNOUNCEMENT
DESCRIPTOR.message_types_by_name['Originator'] = _ORIGINATOR
DESCRIPTOR.message_types_by_name['AnError'] = _ANERROR
DESCRIPTOR.message_types_by_name['Pin'] = _PIN
DESCRIPTOR.message_types_by_name['Signal'] = _SIGNAL
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['Function'] = _FUNCTION
DESCRIPTOR.message_types_by_name['Thread'] = _THREAD
DESCRIPTOR.message_types_by_name['Component'] = _COMPONENT
DESCRIPTOR.message_types_by_name['Ring'] = _RING
DESCRIPTOR.message_types_by_name['Member'] = _MEMBER
DESCRIPTOR.message_types_by_name['Group'] = _GROUP
DESCRIPTOR.message_types_by_name['ProtocolParameters'] = _PROTOCOLPARAMETERS
DESCRIPTOR.message_types_by_name['Vtable'] = _VTABLE
DESCRIPTOR.message_types_by_name['Inst'] = _INST

Instance = _reflection.GeneratedProtocolMessageType('Instance', (_message.Message,), dict(
  DESCRIPTOR = _INSTANCE,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Instance)
  ))
_sym_db.RegisterMessage(Instance)

ServiceAnnouncement = _reflection.GeneratedProtocolMessageType('ServiceAnnouncement', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEANNOUNCEMENT,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.ServiceAnnouncement)
  ))
_sym_db.RegisterMessage(ServiceAnnouncement)

Originator = _reflection.GeneratedProtocolMessageType('Originator', (_message.Message,), dict(
  DESCRIPTOR = _ORIGINATOR,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Originator)
  ))
_sym_db.RegisterMessage(Originator)

AnError = _reflection.GeneratedProtocolMessageType('AnError', (_message.Message,), dict(
  DESCRIPTOR = _ANERROR,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.AnError)
  ))
_sym_db.RegisterMessage(AnError)

Pin = _reflection.GeneratedProtocolMessageType('Pin', (_message.Message,), dict(
  DESCRIPTOR = _PIN,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Pin)
  ))
_sym_db.RegisterMessage(Pin)

Signal = _reflection.GeneratedProtocolMessageType('Signal', (_message.Message,), dict(
  DESCRIPTOR = _SIGNAL,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Signal)
  ))
_sym_db.RegisterMessage(Signal)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), dict(
  DESCRIPTOR = _PARAM,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Param)
  ))
_sym_db.RegisterMessage(Param)

Function = _reflection.GeneratedProtocolMessageType('Function', (_message.Message,), dict(
  DESCRIPTOR = _FUNCTION,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Function)
  ))
_sym_db.RegisterMessage(Function)

Thread = _reflection.GeneratedProtocolMessageType('Thread', (_message.Message,), dict(
  DESCRIPTOR = _THREAD,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Thread)
  ))
_sym_db.RegisterMessage(Thread)

Component = _reflection.GeneratedProtocolMessageType('Component', (_message.Message,), dict(
  DESCRIPTOR = _COMPONENT,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Component)
  ))
_sym_db.RegisterMessage(Component)

Ring = _reflection.GeneratedProtocolMessageType('Ring', (_message.Message,), dict(
  DESCRIPTOR = _RING,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Ring)
  ))
_sym_db.RegisterMessage(Ring)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
  DESCRIPTOR = _MEMBER,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Member)
  ))
_sym_db.RegisterMessage(Member)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), dict(
  DESCRIPTOR = _GROUP,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Group)
  ))
_sym_db.RegisterMessage(Group)

ProtocolParameters = _reflection.GeneratedProtocolMessageType('ProtocolParameters', (_message.Message,), dict(
  DESCRIPTOR = _PROTOCOLPARAMETERS,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.ProtocolParameters)
  ))
_sym_db.RegisterMessage(ProtocolParameters)

Vtable = _reflection.GeneratedProtocolMessageType('Vtable', (_message.Message,), dict(
  DESCRIPTOR = _VTABLE,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Vtable)
  ))
_sym_db.RegisterMessage(Vtable)

Inst = _reflection.GeneratedProtocolMessageType('Inst', (_message.Message,), dict(
  DESCRIPTOR = _INST,
  __module__ = 'machinetalk.protobuf.object_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Inst)
  ))
_sym_db.RegisterMessage(Inst)


_INSTANCE.has_options = True
_INSTANCE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\274\005'))
_SERVICEANNOUNCEMENT.has_options = True
_SERVICEANNOUNCEMENT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\275\005'))
_ORIGINATOR.has_options = True
_ORIGINATOR._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\276\005'))
_ANERROR.has_options = True
_ANERROR._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\277\005'))
_PIN.has_options = True
_PIN._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\300\005'))
_SIGNAL.has_options = True
_SIGNAL._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\301\005'))
_PARAM.has_options = True
_PARAM._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\302\005'))
_FUNCTION.has_options = True
_FUNCTION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\303\005'))
_THREAD.has_options = True
_THREAD._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\304\005'))
_COMPONENT.has_options = True
_COMPONENT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\305\005'))
_RING.has_options = True
_RING._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\306\005'))
_MEMBER.has_options = True
_MEMBER._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\307\005'))
_GROUP.has_options = True
_GROUP._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\310\005'))
_PROTOCOLPARAMETERS.has_options = True
_PROTOCOLPARAMETERS._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\311\005'))
_VTABLE.has_options = True
_VTABLE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\312\005'))
_INST.has_options = True
_INST._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\313\005'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/log.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/log.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\x1emachinetalk/protobuf/log.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/types.proto\"\x8a\x01\n\nLogMessage\x12&\n\x06origin\x18\n \x02(\x0e\x32\x16.machinetalk.MsgOrigin\x12\x0b\n\x03pid\x18\x14 \x02(\x05\x12$\n\x05level\x18\x1e \x02(\x0e\x32\x15.machinetalk.MsgLevel\x12\x0b\n\x03tag\x18( \x02(\t\x12\x0c\n\x04text\x18\x32 \x02(\t:\x06\x92?\x03H\x90\x03')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_LOGMESSAGE = _descriptor.Descriptor(
  name='LogMessage',
  full_name='machinetalk.LogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.LogMessage.origin', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='machinetalk.LogMessage.pid', index=1,
      number=20, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='level', full_name='machinetalk.LogMessage.level', index=2,
      number=30, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='machinetalk.LogMessage.tag', index=3,
      number=40, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='machinetalk.LogMessage.text', index=4,
      number=50, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\220\003')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=255,
)

_LOGMESSAGE.fields_by_name['origin'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._MSGORIGIN
_LOGMESSAGE.fields_by_name['level'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._MSGLEVEL
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), dict(
  DESCRIPTOR = _LOGMESSAGE,
  __module__ = 'machinetalk.protobuf.log_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.LogMessage)
  ))
_sym_db.RegisterMessage(LogMessage)


_LOGMESSAGE.has_options = True
_LOGMESSAGE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\220\003'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/rtapi_message.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import value_pb2 as machinetalk_dot_protobuf_dot_value__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/rtapi_message.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n(machinetalk/protobuf/rtapi_message.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/value.proto\"\x7f\n\rRTAPI_Message\x12\x10\n\x08msglevel\x18\n \x02(\x05\x12,\n\x06\x66ormat\x18\x14 \x02(\t:\x15*** uninitialized ***B\x05\x92?\x02\x08\x64\x12&\n\x03\x61rg\x18\x1e \x03(\x0b\x32\x12.machinetalk.ValueB\x05\x92?\x02\x10\n:\x06\x92?\x03H\xe8\x07')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_value__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_RTAPI_MESSAGE = _descriptor.Descriptor(
  name='RTAPI_Message',
  full_name='machinetalk.RTAPI_Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msglevel', full_name='machinetalk.RTAPI_Message.msglevel', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='format', full_name='machinetalk.RTAPI_Message.format', index=1,
      number=20, type=9, cpp_type=9, label=2,
      has_default_value=True, default_value=_b("*** uninitialized ***").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\010d'))),
    _descriptor.FieldDescriptor(
      name='arg', full_name='machinetalk.RTAPI_Message.arg', index=2,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\020\n'))),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\350\007')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=253,
)

_RTAPI_MESSAGE.fields_by_name['arg'].message_type = machinetalk_dot_protobuf_dot_value__pb2._VALUE
DESCRIPTOR.message_types_by_name['RTAPI_Message'] = _RTAPI_MESSAGE

RTAPI_Message = _reflection.GeneratedProtocolMessageType('RTAPI_Message', (_message.Message,), dict(
  DESCRIPTOR = _RTAPI_MESSAGE,
  __module__ = 'machinetalk.protobuf.rtapi_message_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.RTAPI_Message)
  ))
_sym_db.RegisterMessage(RTAPI_Message)


_RTAPI_MESSAGE.fields_by_name['format'].has_options = True
_RTAPI_MESSAGE.fields_by_name['format']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\010d'))
_RTAPI_MESSAGE.fields_by_name['arg'].has_options = True
_RTAPI_MESSAGE.fields_by_name['arg']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\222?\002\020\n'))
_RTAPI_MESSAGE.has_options = True
_RTAPI_MESSAGE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\350\007'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/task.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2
from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/task.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\x1fmachinetalk/protobuf/task.proto\x12\x0bmachinetalk\x1a machinetalk/protobuf/types.proto\x1a!machinetalk/protobuf/nanopb.proto\"8\n\x0fTaskPlanExecute\x12\x0f\n\x07\x63ommand\x18\n \x01(\t\x12\x0c\n\x04line\x18\x1e \x01(\x0f:\x06\x92?\x03H\xb0\t\",\n\x13TaskPlanBlockDelete\x12\r\n\x05state\x18\n \x02(\x08:\x06\x92?\x03H\xb1\t\"-\n\x14TaskPlanOptionalStop\x12\r\n\x05state\x18\n \x02(\x08:\x06\x92?\x03H\xb2\t\"(\n\x0cTaskPlanOpen\x12\x10\n\x08\x66ilename\x18\n \x02(\t:\x06\x92?\x03H\xb3\t\"R\n\rTaskPlanReply\x12\'\n\x03\x63md\x18\n \x02(\x0e\x32\x1a.machinetalk.ContainerType\x12\x10\n\x08\x65rrormsg\x18\x14 \x01(\t:\x06\x92?\x03H\xb4\t\"#\n\tTaskReply\x12\x0e\n\x06ticket\x18\n \x02(\x07:\x06\x92?\x03H\xb5\t\"^\n\x0cTicketUpdate\x12\x0f\n\x07\x63ticket\x18\n \x02(\x07\x12\'\n\x06status\x18\x14 \x02(\x0e\x32\x17.machinetalk.RCS_STATUS\x12\x0c\n\x04text\x18\x1e \x01(\t:\x06\x92?\x03H\xb6\t')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_TASKPLANEXECUTE = _descriptor.Descriptor(
  name='TaskPlanExecute',
  full_name='machinetalk.TaskPlanExecute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='machinetalk.TaskPlanExecute.command', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line', full_name='machinetalk.TaskPlanExecute.line', index=1,
      number=30, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\260\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=173,
)


_TASKPLANBLOCKDELETE = _descriptor.Descriptor(
  name='TaskPlanBlockDelete',
  full_name='machinetalk.TaskPlanBlockDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.TaskPlanBlockDelete.state', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\261\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=219,
)


_TASKPLANOPTIONALSTOP = _descriptor.Descriptor(
  name='TaskPlanOptionalStop',
  full_name='machinetalk.TaskPlanOptionalStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='machinetalk.TaskPlanOptionalStop.state', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\262\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=266,
)


_TASKPLANOPEN = _descriptor.Descriptor(
  name='TaskPlanOpen',
  full_name='machinetalk.TaskPlanOpen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='machinetalk.TaskPlanOpen.filename', index=0,
      number=10, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\263\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=268,
  serialized_end=308,
)


_TASKPLANREPLY = _descriptor.Descriptor(
  name='TaskPlanReply',
  full_name='machinetalk.TaskPlanReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='machinetalk.TaskPlanReply.cmd', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errormsg', full_name='machinetalk.TaskPlanReply.errormsg', index=1,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\264\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=392,
)


_TASKREPLY = _descriptor.Descriptor(
  name='TaskReply',
  full_name='machinetalk.TaskReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='machinetalk.TaskReply.ticket', index=0,
      number=10, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\265\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=394,
  serialized_end=429,
)


_TICKETUPDATE = _descriptor.Descriptor(
  name='TicketUpdate',
  full_name='machinetalk.TicketUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cticket', full_name='machinetalk.TicketUpdate.cticket', index=0,
      number=10, type=7, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='machinetalk.TicketUpdate.status', index=1,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='machinetalk.TicketUpdate.text', index=2,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\266\t')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=525,
)

_TASKPLANREPLY.fields_by_name['cmd'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._CONTAINERTYPE
_TICKETUPDATE.fields_by_name['status'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._RCS_STATUS
DESCRIPTOR.message_types_by_name['TaskPlanExecute'] = _TASKPLANEXECUTE
DESCRIPTOR.message_types_by_name['TaskPlanBlockDelete'] = _TASKPLANBLOCKDELETE
DESCRIPTOR.message_types_by_name['TaskPlanOptionalStop'] = _TASKPLANOPTIONALSTOP
DESCRIPTOR.message_types_by_name['TaskPlanOpen'] = _TASKPLANOPEN
DESCRIPTOR.message_types_by_name['TaskPlanReply'] = _TASKPLANREPLY
DESCRIPTOR.message_types_by_name['TaskReply'] = _TASKREPLY
DESCRIPTOR.message_types_by_name['TicketUpdate'] = _TICKETUPDATE

TaskPlanExecute = _reflection.GeneratedProtocolMessageType('TaskPlanExecute', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANEXECUTE,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanExecute)
  ))
_sym_db.RegisterMessage(TaskPlanExecute)

TaskPlanBlockDelete = _reflection.GeneratedProtocolMessageType('TaskPlanBlockDelete', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANBLOCKDELETE,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanBlockDelete)
  ))
_sym_db.RegisterMessage(TaskPlanBlockDelete)

TaskPlanOptionalStop = _reflection.GeneratedProtocolMessageType('TaskPlanOptionalStop', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANOPTIONALSTOP,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanOptionalStop)
  ))
_sym_db.RegisterMessage(TaskPlanOptionalStop)

TaskPlanOpen = _reflection.GeneratedProtocolMessageType('TaskPlanOpen', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANOPEN,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanOpen)
  ))
_sym_db.RegisterMessage(TaskPlanOpen)

TaskPlanReply = _reflection.GeneratedProtocolMessageType('TaskPlanReply', (_message.Message,), dict(
  DESCRIPTOR = _TASKPLANREPLY,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskPlanReply)
  ))
_sym_db.RegisterMessage(TaskPlanReply)

TaskReply = _reflection.GeneratedProtocolMessageType('TaskReply', (_message.Message,), dict(
  DESCRIPTOR = _TASKREPLY,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TaskReply)
  ))
_sym_db.RegisterMessage(TaskReply)

TicketUpdate = _reflection.GeneratedProtocolMessageType('TicketUpdate', (_message.Message,), dict(
  DESCRIPTOR = _TICKETUPDATE,
  __module__ = 'machinetalk.protobuf.task_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.TicketUpdate)
  ))
_sym_db.RegisterMessage(TicketUpdate)


_TASKPLANEXECUTE.has_options = True
_TASKPLANEXECUTE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\260\t'))
_TASKPLANBLOCKDELETE.has_options = True
_TASKPLANBLOCKDELETE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\261\t'))
_TASKPLANOPTIONALSTOP.has_options = True
_TASKPLANOPTIONALSTOP._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\262\t'))
_TASKPLANOPEN.has_options = True
_TASKPLANOPEN._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\263\t'))
_TASKPLANREPLY.has_options = True
_TASKPLANREPLY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\264\t'))
_TASKREPLY.has_options = True
_TASKREPLY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\265\t'))
_TICKETUPDATE.has_options = True
_TICKETUPDATE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\266\t'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/nanopb.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/nanopb.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n!machinetalk/protobuf/nanopb.proto\x1a google/protobuf/descriptor.proto\"\x80\x02\n\rNanoPBOptions\x12\x10\n\x08max_size\x18\x01 \x01(\x05\x12\x11\n\tmax_count\x18\x02 \x01(\x05\x12&\n\x08int_size\x18\x07 \x01(\x0e\x32\x08.IntSize:\nIS_DEFAULT\x12$\n\x04type\x18\x03 \x01(\x0e\x32\n.FieldType:\nFT_DEFAULT\x12\x18\n\nlong_names\x18\x04 \x01(\x08:\x04true\x12\x1c\n\rpacked_struct\x18\x05 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0cskip_message\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x18\n\tno_unions\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\r\n\x05msgid\x18\t \x01(\r*Z\n\tFieldType\x12\x0e\n\nFT_DEFAULT\x10\x00\x12\x0f\n\x0b\x46T_CALLBACK\x10\x01\x12\x0e\n\nFT_POINTER\x10\x04\x12\r\n\tFT_STATIC\x10\x02\x12\r\n\tFT_IGNORE\x10\x03*D\n\x07IntSize\x12\x0e\n\nIS_DEFAULT\x10\x00\x12\x08\n\x04IS_8\x10\x08\x12\t\n\x05IS_16\x10\x10\x12\t\n\x05IS_32\x10 \x12\t\n\x05IS_64\x10@:E\n\x0enanopb_fileopt\x12\x1c.google.protobuf.FileOptions\x18\xf2\x07 \x01(\x0b\x32\x0e.NanoPBOptions:G\n\rnanopb_msgopt\x12\x1f.google.protobuf.MessageOptions\x18\xf2\x07 \x01(\x0b\x32\x0e.NanoPBOptions:E\n\x0enanopb_enumopt\x12\x1c.google.protobuf.EnumOptions\x18\xf2\x07 \x01(\x0b\x32\x0e.NanoPBOptions:>\n\x06nanopb\x12\x1d.google.protobuf.FieldOptions\x18\xf2\x07 \x01(\x0b\x32\x0e.NanoPBOptionsB\x1a\n\x18\x66i.kapsi.koti.jpa.nanopb')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_FIELDTYPE = _descriptor.EnumDescriptor(
  name='FieldType',
  full_name='FieldType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FT_DEFAULT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FT_CALLBACK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FT_POINTER', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FT_STATIC', index=3, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FT_IGNORE', index=4, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=330,
  serialized_end=420,
)
_sym_db.RegisterEnumDescriptor(_FIELDTYPE)

FieldType = enum_type_wrapper.EnumTypeWrapper(_FIELDTYPE)
_INTSIZE = _descriptor.EnumDescriptor(
  name='IntSize',
  full_name='IntSize',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IS_DEFAULT', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_8', index=1, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_16', index=2, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_32', index=3, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_64', index=4, number=64,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=422,
  serialized_end=490,
)
_sym_db.RegisterEnumDescriptor(_INTSIZE)

IntSize = enum_type_wrapper.EnumTypeWrapper(_INTSIZE)
FT_DEFAULT = 0
FT_CALLBACK = 1
FT_POINTER = 4
FT_STATIC = 2
FT_IGNORE = 3
IS_DEFAULT = 0
IS_8 = 8
IS_16 = 16
IS_32 = 32
IS_64 = 64

NANOPB_FILEOPT_FIELD_NUMBER = 1010
nanopb_fileopt = _descriptor.FieldDescriptor(
  name='nanopb_fileopt', full_name='nanopb_fileopt', index=0,
  number=1010, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)
NANOPB_MSGOPT_FIELD_NUMBER = 1010
nanopb_msgopt = _descriptor.FieldDescriptor(
  name='nanopb_msgopt', full_name='nanopb_msgopt', index=1,
  number=1010, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)
NANOPB_ENUMOPT_FIELD_NUMBER = 1010
nanopb_enumopt = _descriptor.FieldDescriptor(
  name='nanopb_enumopt', full_name='nanopb_enumopt', index=2,
  number=1010, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)
NANOPB_FIELD_NUMBER = 1010
nanopb = _descriptor.FieldDescriptor(
  name='nanopb', full_name='nanopb', index=3,
  number=1010, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None)


_NANOPBOPTIONS = _descriptor.Descriptor(
  name='NanoPBOptions',
  full_name='NanoPBOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_size', full_name='NanoPBOptions.max_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_count', full_name='NanoPBOptions.max_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_size', full_name='NanoPBOptions.int_size', index=2,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='NanoPBOptions.type', index=3,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='long_names', full_name='NanoPBOptions.long_names', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='packed_struct', full_name='NanoPBOptions.packed_struct', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='skip_message', full_name='NanoPBOptions.skip_message', index=6,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='no_unions', full_name='NanoPBOptions.no_unions', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msgid', full_name='NanoPBOptions.msgid', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=328,
)

_NANOPBOPTIONS.fields_by_name['int_size'].enum_type = _INTSIZE
_NANOPBOPTIONS.fields_by_name['type'].enum_type = _FIELDTYPE
DESCRIPTOR.message_types_by_name['NanoPBOptions'] = _NANOPBOPTIONS
DESCRIPTOR.enum_types_by_name['FieldType'] = _FIELDTYPE
DESCRIPTOR.enum_types_by_name['IntSize'] = _INTSIZE
DESCRIPTOR.extensions_by_name['nanopb_fileopt'] = nanopb_fileopt
DESCRIPTOR.extensions_by_name['nanopb_msgopt'] = nanopb_msgopt
DESCRIPTOR.extensions_by_name['nanopb_enumopt'] = nanopb_enumopt
DESCRIPTOR.extensions_by_name['nanopb'] = nanopb

NanoPBOptions = _reflection.GeneratedProtocolMessageType('NanoPBOptions', (_message.Message,), dict(
  DESCRIPTOR = _NANOPBOPTIONS,
  __module__ = 'machinetalk.protobuf.nanopb_pb2'
  # @@protoc_insertion_point(class_scope:NanoPBOptions)
  ))
_sym_db.RegisterMessage(NanoPBOptions)

nanopb_fileopt.message_type = _NANOPBOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(nanopb_fileopt)
nanopb_msgopt.message_type = _NANOPBOPTIONS
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(nanopb_msgopt)
nanopb_enumopt.message_type = _NANOPBOPTIONS
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(nanopb_enumopt)
nanopb.message_type = _NANOPBOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(nanopb)

DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\030fi.kapsi.koti.jpa.nanopb'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/preview.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/preview.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n\"machinetalk/protobuf/preview.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\"u\n\x08Position\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\t\n\x01z\x18\x05 \x01(\x01\x12\t\n\x01\x61\x18\x06 \x01(\x01\x12\t\n\x01\x62\x18\x07 \x01(\x01\x12\t\n\x01\x63\x18\x08 \x01(\x01\x12\t\n\x01u\x18\t \x01(\x01\x12\t\n\x01v\x18\n \x01(\x01\x12\t\n\x01w\x18\x0b \x01(\x01:\x06\x92?\x03H\xa0\x06\"\xd9\x04\n\x07Preview\x12(\n\x04type\x18\x01 \x02(\x0e\x32\x1a.machinetalk.PreviewOpType\x12\x13\n\x0bline_number\x18\x02 \x01(\x05\x12\"\n\x03pos\x18\x03 \x01(\x0b\x32\x15.machinetalk.Position\x12\x11\n\tfirst_end\x18\x04 \x01(\x01\x12\x12\n\nsecond_end\x18\x05 \x01(\x01\x12\x12\n\nfirst_axis\x18\x06 \x01(\x01\x12\x13\n\x0bsecond_axis\x18\x07 \x01(\x01\x12\x10\n\x08rotation\x18\x08 \x01(\x05\x12\x16\n\x0e\x61xis_end_point\x18\t \x01(\x01\x12\x13\n\x0bxy_rotation\x18\n \x01(\x01\x12\r\n\x05plane\x18\x0b \x01(\x05\x12\x0c\n\x04rate\x18\x0c \x01(\x01\x12\x11\n\tfeed_mode\x18\r \x01(\x05\x12\x0c\n\x04time\x18\x0e \x01(\x01\x12\x0c\n\x04text\x18\x0f \x01(\t\x12\x15\n\rangular_units\x18\x65 \x01(\x01\x12\x14\n\x0clength_units\x18\x66 \x01(\x01\x12\x11\n\tprobetype\x18g \x01(\x05\x12\x33\n\x04kins\x18h \x01(\x0e\x32\x1b.machinetalk.KinematicsType:\x08KT_JOINT\x12\x10\n\x08\x61xismask\x18i \x01(\x05\x12\x10\n\x08g5_index\x18j \x01(\x05\x12\x0e\n\x06pocket\x18k \x01(\x05\x12&\n\x05stype\x18n \x01(\x0e\x32\x17.machinetalk.SourceType\x12\x10\n\x08\x66ilename\x18o \x01(\t\x12\x11\n\tcmdstring\x18p \x01(\t\x12\x12\n\ncall_level\x18q \x01(\x05:\x06\x92?\x03H\xa1\x06*=\n\x0eKinematicsType\x12\x0c\n\x08KT_JOINT\x10\x01\x12\x0f\n\x0bKT_TRIVKINS\x10\x02\x12\x0c\n\x08KT_DELTA\x10\x03*\xe3\x03\n\rPreviewOpType\x12\x15\n\x11PV_STRAIGHT_PROBE\x10\x01\x12\x10\n\x0cPV_RIGID_TAP\x10\x02\x12\x14\n\x10PV_STRAIGHT_FEED\x10\x03\x12\x0f\n\x0bPV_ARC_FEED\x10\x04\x12\x18\n\x14PV_STRAIGHT_TRAVERSE\x10\x05\x12\x15\n\x11PV_SET_G5X_OFFSET\x10\x06\x12\x15\n\x11PV_SET_G92_OFFSET\x10\x07\x12\x16\n\x12PV_SET_XY_ROTATION\x10\x08\x12\x13\n\x0fPV_SELECT_PLANE\x10\t\x12\x18\n\x14PV_SET_TRAVERSE_RATE\x10\n\x12\x14\n\x10PV_SET_FEED_RATE\x10\x0b\x12\x12\n\x0ePV_CHANGE_TOOL\x10\x0c\x12\x19\n\x15PV_CHANGE_TOOL_NUMBER\x10\r\x12\x0c\n\x08PV_DWELL\x10\x0e\x12\x0e\n\nPV_MESSAGE\x10\x0f\x12\x0e\n\nPV_COMMENT\x10\x10\x12\x16\n\x12PV_USE_TOOL_OFFSET\x10\x11\x12\x11\n\rPV_SET_PARAMS\x10\x12\x12\x14\n\x10PV_SET_FEED_MODE\x10\x13\x12\x15\n\x11PV_SOURCE_CONTEXT\x10\x14\x12\x14\n\x10PV_PREVIEW_START\x10\x15\x12\x12\n\x0ePV_PREVIEW_END\x10\x16*F\n\nSourceType\x12\x0f\n\x0bST_NGC_FILE\x10\x01\x12\x11\n\rST_NGC_STRING\x10\x02\x12\x14\n\x10ST_PYTHON_METHOD\x10\x03')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_KINEMATICSTYPE = _descriptor.EnumDescriptor(
  name='KinematicsType',
  full_name='machinetalk.KinematicsType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KT_JOINT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KT_TRIVKINS', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KT_DELTA', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=809,
  serialized_end=870,
)
_sym_db.RegisterEnumDescriptor(_KINEMATICSTYPE)

KinematicsType = enum_type_wrapper.EnumTypeWrapper(_KINEMATICSTYPE)
_PREVIEWOPTYPE = _descriptor.EnumDescriptor(
  name='PreviewOpType',
  full_name='machinetalk.PreviewOpType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PV_STRAIGHT_PROBE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_RIGID_TAP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_STRAIGHT_FEED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_ARC_FEED', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_STRAIGHT_TRAVERSE', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_G5X_OFFSET', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_G92_OFFSET', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_XY_ROTATION', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SELECT_PLANE', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_TRAVERSE_RATE', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_FEED_RATE', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_CHANGE_TOOL', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_CHANGE_TOOL_NUMBER', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_DWELL', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_MESSAGE', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_COMMENT', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_USE_TOOL_OFFSET', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_PARAMS', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SET_FEED_MODE', index=18, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_SOURCE_CONTEXT', index=19, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_PREVIEW_START', index=20, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PV_PREVIEW_END', index=21, number=22,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=873,
  serialized_end=1356,
)
_sym_db.RegisterEnumDescriptor(_PREVIEWOPTYPE)

PreviewOpType = enum_type_wrapper.EnumTypeWrapper(_PREVIEWOPTYPE)
_SOURCETYPE = _descriptor.EnumDescriptor(
  name='SourceType',
  full_name='machinetalk.SourceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ST_NGC_FILE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_NGC_STRING', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ST_PYTHON_METHOD', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1358,
  serialized_end=1428,
)
_sym_db.RegisterEnumDescriptor(_SOURCETYPE)

SourceType = enum_type_wrapper.EnumTypeWrapper(_SOURCETYPE)
KT_JOINT = 1
KT_TRIVKINS = 2
KT_DELTA = 3
PV_STRAIGHT_PROBE = 1
PV_RIGID_TAP = 2
PV_STRAIGHT_FEED = 3
PV_ARC_FEED = 4
PV_STRAIGHT_TRAVERSE = 5
PV_SET_G5X_OFFSET = 6
PV_SET_G92_OFFSET = 7
PV_SET_XY_ROTATION = 8
PV_SELECT_PLANE = 9
PV_SET_TRAVERSE_RATE = 10
PV_SET_FEED_RATE = 11
PV_CHANGE_TOOL = 12
PV_CHANGE_TOOL_NUMBER = 13
PV_DWELL = 14
PV_MESSAGE = 15
PV_COMMENT = 16
PV_USE_TOOL_OFFSET = 17
PV_SET_PARAMS = 18
PV_SET_FEED_MODE = 19
PV_SOURCE_CONTEXT = 20
PV_PREVIEW_START = 21
PV_PREVIEW_END = 22
ST_NGC_FILE = 1
ST_NGC_STRING = 2
ST_PYTHON_METHOD = 3



_POSITION = _descriptor.Descriptor(
  name='Position',
  full_name='machinetalk.Position',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='machinetalk.Position.x', index=0,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='machinetalk.Position.y', index=1,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='machinetalk.Position.z', index=2,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='a', full_name='machinetalk.Position.a', index=3,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='machinetalk.Position.b', index=4,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='machinetalk.Position.c', index=5,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='u', full_name='machinetalk.Position.u', index=6,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v', full_name='machinetalk.Position.v', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w', full_name='machinetalk.Position.w', index=8,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\240\006')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=203,
)


_PREVIEW = _descriptor.Descriptor(
  name='Preview',
  full_name='machinetalk.Preview',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Preview.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='line_number', full_name='machinetalk.Preview.line_number', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos', full_name='machinetalk.Preview.pos', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_end', full_name='machinetalk.Preview.first_end', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second_end', full_name='machinetalk.Preview.second_end', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_axis', full_name='machinetalk.Preview.first_axis', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second_axis', full_name='machinetalk.Preview.second_axis', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rotation', full_name='machinetalk.Preview.rotation', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axis_end_point', full_name='machinetalk.Preview.axis_end_point', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xy_rotation', full_name='machinetalk.Preview.xy_rotation', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='plane', full_name='machinetalk.Preview.plane', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rate', full_name='machinetalk.Preview.rate', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feed_mode', full_name='machinetalk.Preview.feed_mode', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='machinetalk.Preview.time', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='machinetalk.Preview.text', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='angular_units', full_name='machinetalk.Preview.angular_units', index=15,
      number=101, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='length_units', full_name='machinetalk.Preview.length_units', index=16,
      number=102, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probetype', full_name='machinetalk.Preview.probetype', index=17,
      number=103, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kins', full_name='machinetalk.Preview.kins', index=18,
      number=104, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='axismask', full_name='machinetalk.Preview.axismask', index=19,
      number=105, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g5_index', full_name='machinetalk.Preview.g5_index', index=20,
      number=106, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pocket', full_name='machinetalk.Preview.pocket', index=21,
      number=107, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stype', full_name='machinetalk.Preview.stype', index=22,
      number=110, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='machinetalk.Preview.filename', index=23,
      number=111, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cmdstring', full_name='machinetalk.Preview.cmdstring', index=24,
      number=112, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='call_level', full_name='machinetalk.Preview.call_level', index=25,
      number=113, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\241\006')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=807,
)

_PREVIEW.fields_by_name['type'].enum_type = _PREVIEWOPTYPE
_PREVIEW.fields_by_name['pos'].message_type = _POSITION
_PREVIEW.fields_by_name['kins'].enum_type = _KINEMATICSTYPE
_PREVIEW.fields_by_name['stype'].enum_type = _SOURCETYPE
DESCRIPTOR.message_types_by_name['Position'] = _POSITION
DESCRIPTOR.message_types_by_name['Preview'] = _PREVIEW
DESCRIPTOR.enum_types_by_name['KinematicsType'] = _KINEMATICSTYPE
DESCRIPTOR.enum_types_by_name['PreviewOpType'] = _PREVIEWOPTYPE
DESCRIPTOR.enum_types_by_name['SourceType'] = _SOURCETYPE

Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), dict(
  DESCRIPTOR = _POSITION,
  __module__ = 'machinetalk.protobuf.preview_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Position)
  ))
_sym_db.RegisterMessage(Position)

Preview = _reflection.GeneratedProtocolMessageType('Preview', (_message.Message,), dict(
  DESCRIPTOR = _PREVIEW,
  __module__ = 'machinetalk.protobuf.preview_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Preview)
  ))
_sym_db.RegisterMessage(Preview)


_POSITION.has_options = True
_POSITION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\240\006'))
_PREVIEW.has_options = True
_PREVIEW._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\241\006'))
# @@protoc_insertion_point(module_scope)
